.. :changelog:

History
-------

1.0.0 (2025-05-15)
++++++++++++++++++

* Use session to transfer data (safer, more reliable)
* Update support up to Django 5.2, Python 3.13 versions
* Drop support for Python 3.8, Django 4.0 and below

0.1.2 (2023-03-09)
++++++++++++++++++

* Try to rename package to be compatible with poetry (https://github.com/python-poetry/poetry/issues/6996)

0.1.1 (2023-03-08)
++++++++++++++++++

* Update testing and setup.py to support newest Django, Python and django-two-factor-auth

0.1.0 (2022-03-21)
++++++++++++++++++

* First release on PyPI.
